"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.toSplunkEvent = exports.isSplunkLog = exports.isPinoLog = exports.LOG_LABEL_TO_SPLUNK_SEVERITY = exports.LOG_VALUE_TO_LABEL = void 0;

var _isRecord = require("./utils/type/isRecord");

const LOG_VALUE_TO_LABEL = {
  10: 'trace',
  20: 'debug',
  30: 'info',
  40: 'warn',
  50: 'error',
  60: 'fatal'
};
exports.LOG_VALUE_TO_LABEL = LOG_VALUE_TO_LABEL;
const LOG_LABEL_TO_SPLUNK_SEVERITY = {
  trace: {
    level: 'Debug',
    type: 'Info'
  },
  debug: {
    level: 'Debug',
    type: 'Info'
  },
  info: {
    level: 'Important',
    type: 'Info'
  },
  warn: {
    level: 'Important',
    type: 'Warn'
  },
  error: {
    level: 'Important',
    type: 'Error'
  },
  fatal: {
    level: 'Critical',
    type: 'Error'
  }
};
exports.LOG_LABEL_TO_SPLUNK_SEVERITY = LOG_LABEL_TO_SPLUNK_SEVERITY;

const isPinoLog = value => {
  return (0, _isRecord.isRecord)(value) && typeof value.time === 'number' && typeof value.level === 'number' && value.level in LOG_VALUE_TO_LABEL;
};

exports.isPinoLog = isPinoLog;

const isSplunkLog = value => {
  return isPinoLog(value) && (typeof value.msg === 'string' || typeof value.msg === 'undefined') && (typeof value.account === 'string' || typeof value.account === 'undefined') && (typeof value.workflowType === 'string' || typeof value.workflowType === 'undefined') && (typeof value.workflowInstance === 'string' || typeof value.workflowInstance === 'undefined');
};

exports.isSplunkLog = isSplunkLog;

const toSplunkEvent = log => {
  const {
    level,
    time,
    account,
    workflowInstance,
    workflowType,
    ...eventData
  } = log;
  const levelLabel = LOG_VALUE_TO_LABEL[level];
  const severity = LOG_LABEL_TO_SPLUNK_SEVERITY[levelLabel];
  return {
    severity,
    account,
    workflow: {
      type: workflowType !== null && workflowType !== void 0 ? workflowType : '',
      instance: workflowInstance !== null && workflowInstance !== void 0 ? workflowInstance : ''
    },
    data: {
      time: new Date(time).toISOString(),
      ...eventData
    }
  };
};

exports.toSplunkEvent = toSplunkEvent;